/************************************************************************/
/*				                        		*/
/*	  ADCI2CDemoProject 		                                */
/*						                  	*/
/*					                        	*/
/************************************************************************/
/*	Author: Cristian Fatu						*/
/*	Copyright 2012, Digilent Inc.					*/
/************************************************************************/
/*  File Description: 			             		        */
/*					                        	*/
/* This file implements a simple demo application that demonstrates     */
/* how to use the ADCI2C library.				        */
/*									*/
/*	Functionality:							*/
/*									*/
/* In the setup() function, the application initializes                 */
/* the ADCI2C library object.                                           */
 /* In the loop() function, the application reads the physical values   */
/*   corresponding to channels 0 and 1 of AD converter and displays     */
/*  them on serial monitor.				                */
/*					                        	*/
/*	Required Hardware:						*/
/*	  1. Cerebot MX4cK    					        */
/*	  2. PmodAD2 - connected to the I2C#2 interface via MTE cables      */
/************************************************************************/
/*  Revision History:			        			*/
/*					                        	*/
/*	01/10/2012(CristianF): created	       			        */
/*						                     	*/
/************************************************************************/

/* -------------------------------------------------------------------- */
/*				Include File Definitions  	        */
/* -------------------------------------------------------------------- */
#include <ADCI2C.h>

#include <Wire.h> // Wire library header must be included in the sketch

/* -------------------------------------------------------------------- */
/*				Global Variables		        */
/* -------------------------------------------------------------------- */
  ADCI2C myADCI2C; // the library object
  char sMsg[100];  // character string to keep message that is displayed on serial monitor

/* -------------------------------------------------------------------- */
/*	               Procedure Definitions	                        */
/* -------------------------------------------------------------------- */
/***	setup
**
**	Parameters:
**		none
**
**	Return Value:
**		none
**
**	Errors:
**		none
**
**	Description:
**		 Performs basic initialization.		
/*** ---------------------------------------------------------- ***/
void setup()
{ 
  //Create a connection to display the data on the serial monitor.
  Serial.begin(9600);
  
  // initialize PmodADCI2C on I2C #1
  myADCI2C.begin(); 
}

/*** ---------------------------------------------------------- ***/
/***	loop
**
**	Parameters:
**		none
**
**	Return Value:
**		none
**
**	Errors:
**		none
**
**	Description:
**		Main program module. Enters the main program loop.
/*** ---------------------------------------------------------- ***/
void loop()
{  
  float f0, f1;
  myADCI2C.GetPhysicalValues2Ch(f0, f1);  // read physical value
  sprintf(sMsg, "Ch0 : %f, Ch1 : %f", f0, f1); // format text to be displayed 
  Serial.println(sMsg);  // display text on serial monitor
}
